package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import org.apache.commons.lang3.StringUtils;

import java.util.*;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.regex.Pattern;
import java.util.stream.Collectors;

import static com.winhc.bigdata.udf.GetCompanyChangeInfo.splitDate;
import static com.winhc.bigdata.udf.GetConstructionBidInfo.md5;
import static com.winhc.bigdata.udf.GetConstructionPermitInfo.concatws;
import static com.winhc.bigdata.utils.CompanyUtils.cleanup;

/**
 * @author: 主键规则
 * 2021/8/30 16:57
 */
public class CourtAnnouncement extends UDF {

    private static final Pattern pattern = Pattern.compile("[^\\u4e00-\\u9fa5a-zA-Z\\(\\)（）.]");

    public List<String> evaluate(String case_no, String announcement_type, String publish_date, String court_name, String plaintiff, String litigant, String plaintiff_info, String litigant_info) {

        String r1 = md5(cleanup(concatws("", case_no, announcement_type, splitDate(publish_date), court_name, plaintiff, litigant)));

        List<String> pl = split(plaintiff);
        List<String> li = split(litigant);
        pl.sort(Collections.reverseOrder());
        li.sort(Collections.reverseOrder());

        String r2 = md5(cleanup(concatws("", case_no, announcement_type, splitDate(publish_date), court_name,
                String.join(",", pl), String.join(",", li))));


        List<String> pl2 = split(plaintiff);
        List<String> li2 = split(litigant);
        Collections.sort(pl2);
        Collections.sort(li2);

        String r3 = md5(cleanup(concatws("", case_no, announcement_type, splitDate(publish_date), court_name,
                String.join(",", pl2), String.join(",", li2))));

        List<String> list1 = Optional.ofNullable(JSON.parseArray(plaintiff_info)).
                orElse(new JSONArray())
                .toJavaList(JSONObject.class).stream()
                .map(x -> x.getString("name"))
                .filter(StringUtils::isNotBlank).sorted().collect(Collectors.toList());

        List<String> list2 = Optional.ofNullable(JSON.parseArray(litigant_info)).
                orElse(new JSONArray())
                .toJavaList(JSONObject.class).stream()
                .map(x -> x.getString("name"))
                .filter(StringUtils::isNotBlank).sorted().collect(Collectors.toList());
        String r4 = md5(cleanup(concatws("", case_no, announcement_type, splitDate(publish_date), court_name,
                String.join(",", list1), String.join(",", list2))));


        return Arrays.asList(r1, r2, r3, r4);
    }

    public List<String> split(String str) {
        if (StringUtils.isBlank(str)) return new ArrayList<>();
        String[] res = pattern.split(str);
        return Arrays.asList(res);
    }

    public static void main(String[] args) {
        CourtAnnouncement j = new CourtAnnouncement();
        String case_no = "（2023）浙0602民初9753号";
        String announcement_type = "裁判文书";
        String publish_date = "2024-01-23";
        String court_name = "绍兴市越城区人民法院";
        String plaintiff = "深圳农村商业银行股份有限公司广西柳江支行";
        String litigant = "杨国万,李指妹,李满妹";
        String plaintiff_info = "[{\"name\":\"张志祥\",\"litigant_id\":\"\"}]";

        String litigant_info = "[{\"name\":\"陈学翔\",\"litigant_id\":\"\"},{\"name\":\"中国人民财产保险股份有限公司绍兴市分公司\",\"litigant_id\":\"a7c335d0e597b01e727b4747a8a5727c\"}]";
        System.out.println(j.evaluate(case_no, announcement_type, publish_date, court_name, plaintiff, litigant, plaintiff_info, litigant_info));
        System.out.println(j.split("JONAH CHONGHO HONG,JINGNAN JIANG"));
        System.out.println(j.split("陈华辉,何李红,陈贵亮,陈赐容,陈凤群"));
        System.out.println(j.split("施兴成、罗粉扣"));
        System.out.println(j.split("倪金坤、倪阿美、倪俊意、江春豪、沈伟忠、顾美珍、倪东林、戴长芹、沈富明、沈益民"));
        System.out.println();

    }

}
