package com.winhc.bigdata.udf;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.alibaba.fastjson.JSONPath;
import com.aliyun.odps.udf.UDF;
import com.aliyun.odps.utils.StringUtils;
import com.google.common.collect.ImmutableMap;
import com.winhc.bigdata.bean.BaseCaseInfo;
import com.winhc.bigdata.bean.CaseInfo;
import com.winhc.bigdata.bean.CaseInfoName;
import com.winhc.bigdata.udf.justice.CaseNoPartyTitleParseUtilCopy;

import java.util.*;
import java.util.stream.Collectors;
import java.util.stream.Stream;

/**
 * @Author: π
 * @Description: resultLabel获取
 */
public class get_result_label extends UDF {

    public String evaluate(String info) {

        if (StringUtils.isBlank(info)) {
            return null;
        }

        List<BaseCaseInfo> res = new ArrayList<>();
        try {
            res = new ArrayList<>(JSON.parseArray(info).toJavaList(BaseCaseInfo.class));

        }catch (Exception e){
            return null;
        }

        if(res.isEmpty()){
            return null;
        }
        String rr = resultLabel(res);

        return rr;
    }

    public static List<String> law_tns = Arrays.asList("3", "7", "5", "6");

    /**
     * 1.取裁判文书     result_label
     * 2.执行到位      司法案件包含失信、被执、限高、终本四个维度的任何一个，并且deleted=1
     * 3.部分执行到位   司法案件包含非历史终本案件，并且no_exec_amount小于exec_amount
     *
     * @param data
     * @return
     */
    public static String resultLabel(List<BaseCaseInfo> data) {
        if (data == null || data.isEmpty()) return null;
        //1.文书label
        HashSet<String> set = data.stream()
                .filter(f -> "0".equals(f.getFlag()))
                .flatMap(x -> {
                    Stream<String> rr = Optional.ofNullable(JSON.parseArray(x.getResult_label())).orElse(new JSONArray())
                            .toJavaList(String.class)
                            .stream().filter(StringUtils::isNotBlank);
                    return rr;
                }).filter(StringUtils::isNotBlank)
                .collect(Collectors.toCollection(HashSet::new));
        //2.执行label
        List<BaseCaseInfo> zxr_list = data.stream()
                .filter(f -> law_tns.contains(f.getFlag()))
                .collect(Collectors.toList());

        List<BaseCaseInfo> res_2 = zxr_list.stream()
                .filter(f -> {
                    return "0".equals(f.getDeleted());
                })
                .collect(Collectors.toList());

        if (zxr_list.size() > 0 && res_2.size() == 0) {
            set.add("执行到位");
        }
        //3.终本label
        List<BaseCaseInfo> res_3 = data.stream()
                .filter(f -> {
                    boolean ee = "6".equals(f.getFlag());

                    String deleted = f.getDeleted();
                    Double no_exec_amount = f.getNo_exec_amount();
                    boolean flag = false;
                    if (no_exec_amount != null && no_exec_amount > 0) {
                        flag = true;
                    }
                    return ee && "0".equals(deleted) && flag;
                }).collect(Collectors.toList());
        if (res_3.size() > 0) {
            set.add("部分执行到位");
        }
        return set.size() > 0 ? JSON.toJSONString(set) : null;
    }

    public static void main(String[] args) {
        String jsons = "[{\"flag\":\"3\",\"detail_id\":\"00bed47c2ac191106c21c44b4451b30d\",\"result_label\":null,\"no_exec_amount\":null,\"deleted\":\"1\"},{\"flag\":\"5\",\"detail_id\":\"00bed47c2ac191106c21c44b4451b30d\",\"result_label\":null,\"no_exec_amount\":null,\"deleted\":\"1\"}]";
        jsons = "[{\"flag\":\"0\",\"detail_id\":\"0001290e75b6c1e23d95d6175f603ebf\",\"result_label\":\"[\\\"和解\\\"]\",\"no_exec_amount\":null,\"deleted\":\"0\"}]";
        String jsons1 = "[{\"flag\":\"3\",\"detail_id\":\"00c7bcec4321ac02f8d832f5413726dc\",\"result_label\":null,\"no_exec_amount\":null,\"deleted\":\"0\"},{\"flag\":\"5\",\"detail_id\":\"00c7bcec4321ac02f8d832f5413726dc\",\"result_label\":null,\"no_exec_amount\":null,\"deleted\":\"0\"},{\"flag\":\"6\",\"detail_id\":\"00c7bcec4321ac02f8d832f5413726dc\",\"result_label\":null,\"no_exec_amount\":\"82360\",\"deleted\":\"0\"},{\"flag\":\"7\",\"detail_id\":\"a7dddae90a4c06685db1a668174a0ef5\",\"result_label\":null,\"no_exec_amount\":null,\"deleted\":\"1\"}]";
        get_result_label n = new get_result_label();
        System.out.println(n.evaluate(jsons));
        //System.out.println(n.evaluate(jsons1));
    }

}


