package com.winhc.bigdata.udf.justice;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDF;
import com.winhc.bigdata.bean.Entity;
import com.winhc.bigdata.bean.case_no.CaseNoTitleEntity;
import com.winhc.bigdata.utils.BaseUtils;
import com.winhc.bigdata.utils.CaseNoPropertiesUtils;
import org.apache.commons.lang3.StringUtils;

import java.util.*;
import java.util.stream.Collectors;

/**
 * @Author: XuJiakai
 * 2024/1/15 15:54
 * <p>
 * function name: party_summary
 */
public class PartySummaryUDF extends UDF {


    private static final Map<String, String> TITLE_SUMMARY_MAP = new HashMap<String, String>() {
        {
            put("再审申请人", "申请人");
            put("原告", "原告");
            put("被强制医疗人", "其他");
            put("被上诉人", "被上诉人");
            put("原审原告", "其他");
            put("赔偿义务机关", "其他");
            put("原公诉机关", "其他");
            put("救助申请人", "申请人");
            put("罪犯", "其他");
            put("原审被告", "其他");
            put("引渡请求国", "其他");
            put("申诉人", "其他");
            put("当事人", "其他");
            put("被告人", "其他");
            put("被申诉人", "其他");
            put("原申请人", "其他");
            put("被请求引渡人", "其他");
            put("申请人", "申请人");
            put("复议申请人", "申请人");
            put("申请执行人", "申请执行人");
            put("赔偿请求人", "其他");
            put("抗诉机关", "其他");
            put("被申请人", "被申请人");
            put("原被申请人", "其他");
            put("原审被告人", "其他");
            put("被执行人", "被执行人");
            put("上诉人", "上诉人");
            put("被告", "被告");
            put("复议被申请人", "被申请人");
            put("申请复议人", "其他");
            put("异议人", "其他");
            put("申请机关", "其他");
            put("公诉人", "其他");
            put("第三人", "第三人");

        }
    };

    private static String getTitleClassesByMap(String title) {
        return TITLE_SUMMARY_MAP.getOrDefault(title, "其他");
    }

    private static String getTitleClasses(String title) {
        if (StringUtils.isEmpty(title)) {
            return "其他";
        }
        if (title.contains("被申请人")) {
            return "被申请人";
        }
        if (title.contains("申请人")) {
            return "申请人";
        }
        if (title.contains("申请执行人")) {
            return "申请执行人";
        }
        if (title.contains("被执行人")) {
            return "被执行人";
        }
        if (title.contains("被上诉人")) {
            return "被上诉人";
        }
        if (title.contains("上诉人")) {
            return "上诉人";
        }
        if (title.contains("第三人")) {
            return "第三人";
        }
        if (title.contains("原审")) {
            return "其他";
        }
        if (title.contains("原告")) {
            return "原告";
        }
        if (title.contains("被告")) {
            return "被告";
        }
        return "其他";
    }

    private static List<String> partyList(String title_classes, JSONArray litigant_id) {
        if (litigant_id == null || litigant_id.isEmpty()) {
            return null;
        }
        List<String> result = new ArrayList<>();
        for (int i = 0; i < litigant_id.size(); i++) {
            JSONObject jsonObject = litigant_id.getJSONObject(i);
            String name = jsonObject.getString("name");
            String keyno = jsonObject.getString("litigant_id");
            if (StringUtils.isNotEmpty(name) && StringUtils.isNotEmpty(keyno)) {
                result.add(keyno + "_" + title_classes);
            }
        }
        return result;
    }

    public static List<String> getPartySummary(String party_info_new) {
        List<String> result = new ArrayList<>();
        try {
            if (StringUtils.isEmpty(party_info_new)) {
                return result;
            }
            JSONArray jsonArray = JSONObject.parseArray(party_info_new);
            for (int i = 0; i < jsonArray.size(); i++) {
                JSONObject item = jsonArray.getJSONObject(i);
//                String titleClasses = getTitleClasses(item.getString("title_original"));
                String titleClasses = getTitleClassesByMap(item.getString("title_std"));
                JSONArray party_info = item.getJSONArray("party_info");
                List<String> strings = partyList(titleClasses, party_info);
                if (strings != null && !strings.isEmpty()) {
                    result.addAll(strings);
                }
            }
        } catch (Exception e) {
        }
        return result;
    }


    public String evaluate(String party_info_new) {
        if (StringUtils.isEmpty(party_info_new)) {
            return null;
        }
        try {
            List<String> partySummary = getPartySummary(party_info_new);
            if (partySummary == null || partySummary.isEmpty()) {
                return null;
            }
            return BaseUtils.toString(partySummary);
        } catch (Exception e) {
            return null;
        }
    }

    public static void main(String[] args) {
//        String res = new PartySummaryUDF().evaluate("[{\"party_info\":[{\"litigant_id\":\"\",\"name\":\"平安保险东莞分公司\"}],\"show_level\":0,\"title_original\":\"原告\",\"title_std\":\"原告\"},{\"party_info\":[{\"litigant_id\":\"\",\"name\":\"沧州顺驰汽车公司\"},{\"litigant_id\":\"\",\"name\":\"崔建伟\"}],\"show_level\":1,\"title_original\":\"被告\",\"title_std\":\"被告\"}]");
//        System.out.println(res);
        Entity<List<String>, Map<String, Set<CaseNoTitleEntity>>> caseNoKeyword =
                CaseNoPropertiesUtils.getCaseNoKeyword();
        Set<String> set = new HashSet<>();

        Collection<Set<CaseNoTitleEntity>> values = caseNoKeyword._2.values();
        for (Set<CaseNoTitleEntity> value : values) {
            for (CaseNoTitleEntity caseNoTitleEntity : value) {
                Set<String> collect = caseNoTitleEntity.getAll().stream().flatMap(Collection::stream).collect(Collectors.toSet());
                set.addAll(collect);
                set.addAll(caseNoTitleEntity.getCore());
            }
        }
        Set<String> ss = new HashSet<>();
        for (String s : set) {
            System.out.println("tree.build_tree('"+s+"')");
//            ss.add(getTitleClassesByMap(s));
//            System.out.println(s + " " + getTitleClassesByMap(s));
        }
//        System.out.println(ss);
    }
}
