package com.winhc.bigdata.udtf.judgment_doc;

import com.alibaba.fastjson.JSONObject;
import com.aliyun.odps.udf.UDFException;
import com.aliyun.odps.udf.UDTF;
import com.aliyun.odps.udf.annotation.Resolve;
import com.winhc.bigdata.udtf.judgment_doc.entity.JudgmentDocumentSummaryEntity;
import com.winhc.bigdata.udtf.judgment_doc.utils.JudgmentDocumentUtils;
import com.winhc.bigdata.utils.BaseUtils;

import java.io.IOException;
import java.util.List;

/**
 * @Author: XuJiakai
 * 2024/5/23 9:41
 * 根据odps文书表，生成hologres的摘要
 *
 * input args:  rowkey,court_name,case_amt,case_reason_level_1,case_reason_level_2,case_reason_level_3,case_reason_level_4,case_reason,yg_lawyer,plaintiff_info,bg_lawyer,defendant_info
 * output args: base_lawyer_id,rowkey,case_reason_std,court_name,case_amt,company_id
 */
@Resolve(value="*->string,string,array<string>,string,string,array<string>")
public class JudgmentDocumentSummaryUDTF extends UDTF{
    @Override
    public void process(Object[] objects) throws UDFException, IOException {
        JSONObject jsonObject = new JSONObject();
        jsonObject.put("rowkey", objects[0]);
        jsonObject.put("court_name", objects[1]);
        jsonObject.put("case_amt", objects[2]);
        jsonObject.put("case_reason_level1", objects[3]);
        jsonObject.put("case_reason_level2", objects[4]);
        jsonObject.put("case_reason_level3", objects[5]);
        jsonObject.put("case_reason_level4", objects[6]);
        jsonObject.put("case_reason", objects[7]);
        jsonObject.put("yg_lawyer", objects[8]);
        jsonObject.put("plaintiff_info", objects[9]);
        jsonObject.put("bg_lawyer", objects[10]);
        jsonObject.put("defendant_info", objects[11]);
        jsonObject.put("party_info_new", objects[12]);

        List<JudgmentDocumentSummaryEntity> hologresData = JudgmentDocumentUtils.getHologresData(jsonObject);

        for (JudgmentDocumentSummaryEntity item : hologresData) {
            forward(item.getBase_lawyer_id(),item.getRowkey(), item.getCase_reason_std(),item.getCourt_name(),item.getCase_amt(),item.getCompany_id());
        }
    }
}
